<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2018.3/1751405
 */

namespace Application\Permissions;

use Workflow\Model\IWorkflow;
use Application\Config\ConfigManager;
use Zend\ServiceManager\ServiceLocatorInterface as ServiceLocator;
use Application\Permissions\Exception\ForbiddenException;

/**
 * A class following the 'permissions' pattern to check configuration values to see if
 * access is allowed to certain features. Using the 'permissions' service directly implies
 * 'authenticated' so this class can enforce without requiring 'authenticated'.
 * @package Application\Permissions
 */
class ConfigCheck
{
    protected $serviceLocator = null;

    /**
     * Ensure we get a service locator on construction.
     *
     * @param   ServiceLocator  $serviceLocator     the service locator to use
     */
    public function __construct(ServiceLocator $serviceLocator)
    {
        $this->serviceLocator = $serviceLocator;
    }

    /**
     * Ensures that all of the provided checks pass
     * @param array     $checks         Checks to perform. Valid values are 'workflow' and any allowed by the
     *                                  'permissions' module. Checks unknown to this class are passed on to
     *                                  'permissions'.
     * @throws ForbiddenException
     * @throws \Application\Config\ConfigException
     */
    public function enforce($checks)
    {
        $checks = (array) $checks;
        foreach ($checks as $check) {
            switch ($check) {
                case IWorkflow::WORKFLOW:
                    if (!ConfigManager::getValue(
                        $this->serviceLocator->get('config'),
                        ConfigManager::WORKFLOW_ENABLED,
                        false
                    )) {
                        throw new ForbiddenException("Workflows are not enabled");
                    }
                    break;
                default:
                    $this->serviceLocator->get('permissions')->enforce($check);
                    break;
            }
        }
    }
}
